#!/usr/bin/env python
# -*- coding: iso-8859-15 -*-
#
# Extracting script for Image Reduction application
#
# Author: Stéphane POIRIER, Raphaël GIRARDOT, Sahbi THAIRI
# date  : 2019/08/01
#
# version: 1.9
#
# usage: python extractor.py <path/to/nexus_file> <destination/path>
#


# generic modules
import sys
import os
import os.path
import re
import fnmatch



def parseFile(file):
    fileInfo = {'indexStart': None, 'lines':[]}
    indexStart = -1
    headerSeparator = '#####################################################################################################'
    for (i, line) in enumerate(file):
            if headerSeparator in line:
                indexStart = i+1
                fileInfo["indexStart"] = indexStart
            fileInfo["lines"].append(line)
            
    return fileInfo

    
def mergeLines(strLine1,strLine2,characterSplit1,characterSplit2,addNewLine,indice):
    strLine1 = strLine1.replace('\n',',')
    strLine2 = strLine2.replace('\n',',')
    splitLine1 = strLine1.split(characterSplit1)
    splitLine2 = strLine2.split(characterSplit2)
    finalList = []
    newLine = ","

    if len(splitLine2) == len(splitLine1):
        for i in range(len(splitLine1)-1):
            if splitLine1[i].lower() == 'nan':
                if splitLine2[i].lower() == 'nan':
                    finalList.append('NAN')
                else :
                    finalList.append(splitLine2[i])
            else :
                if splitLine2[i].lower() == 'nan':
                    finalList.append(splitLine1[i])
                 
                else :
                    finalList.append(str((float(splitLine2[i])+float(splitLine1[i])/2)))
            
  
    newLine = newLine.join(finalList)
    if(addNewLine):
        newLine = newLine +'\n'
    return newLine
                    
def process_folder(pathFolder, outputFileName):
    print("Processing folder " + pathFolder)
    files = os.listdir(pathFolder)
    indexStart = -1
    headerSeparator = '#####################################################################################################'

   # contF.close()
    for infile in files:
        if fnmatch.fnmatch(infile, '*.dat'):
            with open(os.path.join(pathFolder, infile),"r") as fin:
                if indexStart == -1 :
                    fileInfo = parseFile(fin)
                    indexStart = fileInfo["indexStart"]+1
                    listTmpFile = fileInfo["lines"]
                    listOutputLines = listTmpFile[indexStart:len(listTmpFile)]

                else :
                    with open(outputFileName,"w") as f:
                        print("opening "+ outputFileName)
                        listTmpFile = fin.readlines()
                        addNewLine = True;
                        for i in range(len(listOutputLines)):
                            if listOutputLines is not None :
                                if i == len(listOutputLines)-1:
                                    addNewLine = False
                                listOutputLines[i] = mergeLines(listOutputLines[i],listTmpFile[i+indexStart],",",",",addNewLine,i)
                        if listOutputLines is not None:
                            for j in range(len(listOutputLines)):
                                f.write(str(listOutputLines[j]))

                            
                        f.close()    
                                  
            fin.close()                     
    print("contanetation finished")                
# ------------------------------------------------------------------------------
# Entry point
# ------------------------------------------------------------------------------


if __name__ == "__main__":
    process_folder(sys.argv[1], sys.argv[2])
    